aboutsummaryrefslogtreecommitdiffstats
path: root/epan/stats_tree_priv.h
diff options
context:
space:
mode:
Diffstat (limited to 'epan/stats_tree_priv.h')
-rw-r--r--epan/stats_tree_priv.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/stats_tree_priv.h b/epan/stats_tree_priv.h
index 4fe77293b4..6de4099c87 100644
--- a/epan/stats_tree_priv.h
+++ b/epan/stats_tree_priv.h
@@ -189,9 +189,9 @@ WS_DLL_PUBLIC void stats_tree_reinit(void *p_st);
/* callback for destoy */
WS_DLL_PUBLIC void stats_tree_free(stats_tree *st);
/** given an optarg splits the abbr part
and returns a newly allocated buffer containing it */
-WS_DLL_PUBLIC gchar *stats_tree_get_abbr(const gchar *optarg);
+WS_DLL_PUBLIC gchar *stats_tree_get_abbr(const gchar *ws_optarg);
/** obtains a stats tree from the registry given its abbr */
WS_DLL_PUBLIC stats_tree_cfg *stats_tree_get_cfg_by_abbr(const char *abbr);
@@ -189,9 +189,9 @@ WS_DLL_PUBLIC void stats_tree_reinit(void *p_st);
/* callback for destoy */
WS_DLL_PUBLIC void stats_tree_free(stats_tree *st);
-/** given an optarg splits the abbr part
+/** given an ws_optarg splits the abbr part
and returns a newly allocated buffer containing it */